#
# spec file for package python-aioresponses
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-aioresponses
Version:        0.7.4
Release:        1.5
Summary:        Python module for mocking out requests made by ClientSession from aiohttp
License:        MIT
URL:            https://github.com/pnuckowski/aioresponses
Source:         https://files.pythonhosted.org/packages/source/a/aioresponses/aioresponses-%{version}.tar.gz
BuildRequires:  %{python_module aiohttp >= 2.0.0}
BuildRequires:  %{python_module ddt >= 1.1.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pytest >= 3.8.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing}
BuildRequires:  %{python_module yarl}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  (python3-asynctest if python3-base < 3.8)
BuildRequires:  (python36-asynctest if python36-base)
Requires:       python-aiohttp >= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
This is a Python module for mocking out requests made by ClientSession
from the aiohttp package.

%prep
%setup -q -n aioresponses-%{version}

%build
export LC_ALL=en_US.UTF-8
%python_build

%install
export LC_ALL=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LC_ALL=en_US.UTF-8
# disable tests which try to access external network
skiptests+="test_address_as_instance_of_url_combined_with_pass_through"
skiptests+=" or test_pass_through_with_origin_params"
%pytest -k "not ($skiptests)"

%files %{python_files}
%doc AUTHORS AUTHORS.rst ChangeLog README.rst
%license LICENSE
%{python_sitelib}/aioresponses
%{python_sitelib}/aioresponses-%{version}-py*.egg-info

%changelog
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.4:
  * bump py36 to ubuntu 20.04
  * restore 3.6
  * Adjust github actions test workflow
  * Fix python versions in env list
  * Add documentation for repeat argument
  * Add compat module
  * fix long line by adding line breaks
  * shorten comment to obey line length limit
  * split typing and assignment to avoid long line
  * Avoid type confusion by explicitly typing as \`ClientResponse\`
  * ignore false positive mypy warning when \`url\_or\_pattern\` is a
    \`Pattern\`
  * add \`py.typed\` to MANIFEST.in
  * add \`py.typed\` file to package data in setup.py
  * fix version after release was tagged/released
  * Extend  for arguments
  * Init assert\_called
  * Fix type annotations
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.3:
  * Support binary bodies in responses
  * fix flake8
  * move RequestInfo to compat
  * drop \`.travis.yml\`
  * basic CI using github actions
  * (feat) add unit tests
  * (feat) allow for callbacks to be called before raising of exception
  * add \`py.typed\` (PEP 561)
  * Fix setuptools warnings by replacing dashes in keys with underscores
  * fix version parsing
  * version 0.7.2
  * Update aioresponses/core.py
  * adding catch to ignore ValueError when deepcopy is unsuccessful
* Mon Jan 18 2021 Matej Cepl <mcepl@suse.com>
- Remove unused patch pr_174.patch
* Sun Jan 17 2021 Benjamin Greiner <code@bnavigator.de>
- Update to v0.7.1
  * Fix compatibility with aiohttp 3.7
  * remove asynctest from compat.py
  * Python 3.9 compatibility
- drop pr_174.patch merged upstream
- fix python version requirement, require asynctest for python36
  again
* Wed Oct 28 2020 John Vandenberg <jayvdb@gmail.com>
- Remove no longer necessary aioresponses-replace-asynctest.patch
- Add pr_174.patch to add compatibility with aiohttp 3.7.0
- Update to v0.7.0
  * fixes race condition while removing matchers
  * drop support for py3.5 and aiohttp2.x
  * replace asynctest with native Python 3.8 unittest
* Tue Aug 11 2020 Benjamin Greiner <code@bnavigator.de>
- replace asynctest with native python 3.8 unittest async test class
  * aioresponses-replace-asynctest.patch
  * gh#pnuckowski/aioresponses#166
- drop disable-online-test.patch and deselect by pytest call
* Mon Jun  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.6.4
  * Load response cookies from headers
  * BaseException handling(in Pyhton 3.8 asyncio.CancelError,
    asyncio.TimeoutError are subclass of BaseException)
  * exception can be as class or as object of exception(Exception or Exception())
  * Change method to GET for redirect after POST request.
  * set request_info on response rather than a mock
  * Avoid failure in case one of the request arguments cannot be deep copied
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.6.2
  * Save every received request. Even when no response is subscribed.
  * Ensure that a copy of kwargs is stored in request
  * remove overly verbose Exception
  * assert the correct ClientConnectionError
* Wed Oct  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.1:
  * no upstream changelog
* Thu Apr 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Lower the ddt requirement as it is not really needed
* Sun Mar  3 2019 Ondřej Súkup <mimi.vx@gmail.com>
- cleanup deps
* Thu Feb 28 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependencies
- Update to v0.6.0
  * Move internal stuff and CallbackResult class to the core module
  * Add CallbackResult class for returning responses from callbacks
  * Expose build_response method
  * Add Python 3.7 for tox
  * Add callbacks to provide dynamic responses
* Fri Nov 23 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase / full sentences in summary / description.
* Thu Nov 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Mon Nov 19 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.5.0
- Include patch to disable online test
  + disable-online-test.patch
